@@ -33,19 +33,18 @@ if [ ! -d "PyNormaliz" ]; then
     git clone https://github.com/Normaliz/PyNormaliz
 fi
 
-if [ ! -d "PyQNormaliz" ]; then
-    git clone https://github.com/Normaliz/PyQNormaliz
-fi
-
 cd PyNormaliz
 
+
+export NORMALIZ_LOCAL_DIR="${PREFIX}"
+
 if [ -x "$PYTHON3" ]; then
-    $PYTHON3 setup.py build_ext --include-dirs="${PREFIX}/include" --library-dirs="${PREFIX}/lib"
+    rm -rf build
     $SUDO $PYTHON3 setup.py install $PYTHON_USER
 fi
 
 if [ -x "$PYTHON2" ]; then
-    $PYTHON2 setup.py build_ext --include-dirs="${PREFIX}/include" --library-dirs="${PREFIX}/lib"
+    rm -rf build
     $SUDO $PYTHON2 setup.py install $PYTHON_USER
 fi
 
