@@ -2,13 +2,15 @@
 
 set -e
 
-if [ "$GMP_INSTALLDIR" != "" ]; then
-    CPPFLAGS="${CPFFLAGS} -I${GMP_INSTALLDIR}/include"
-    LDFLAGS="${LDFLAGS} -L${GMP_INSTALLDIR}/lib"
-fi
+echo "::group:e-antic"
 
 source $(dirname "$0")/common.sh
 
+if [ "$GMP_INSTALLDIR" != "" ]; then
+    CPPFLAGS="${CPPFLAGS} -I${GMP_INSTALLDIR}/include"
+    LDFLAGS="${LDFLAGS} -L${GMP_INSTALLDIR}/lib"
+fi
+
 ## script for the installation of e-antic for the use in libnormaliz
 E_ANTIC_VERSION=0.1.8
 E_ANTIC_URL="http://www.labri.fr/perso/vdelecro/e-antic/e-antic-${E_ANTIC_VERSION}.tar.gz"
