@@ -2,10 +2,12 @@
 
 set -e
 
+echo "::group::nauty"
+
 source $(dirname "$0")/common.sh
 
 if [ "$GMP_INSTALLDIR" != "" ]; then
-    CPPFLAGS="${CPFFLAGS} -I${GMP_INSTALLDIR}/include"
+    CPPFLAGS="${CPPFLAGS} -I${GMP_INSTALLDIR}/include"
     LDFLAGS="${LDFLAGS} -L${GMP_INSTALLDIR}/lib"
 fi
 
@@ -28,7 +30,7 @@ fi
 cd nauty${NAUTY_VERSION}
 
 # configure & compile
-./configure
+./configure --enable-tls
 make all -j4 CFLAGS="-fPIC -O3"
 mkdir -p ${PREFIX}/include/nauty
 cp nauty.h ${PREFIX}/include/nauty
