@@ -1,6 +1,6 @@
 /*
  * Normaliz
- * Copyright (C) 2007-2019  Winfried Bruns, Bogdan Ichim, Christof Soeger
+ * Copyright (C) 2007-2021  W. Bruns, B. Ichim, Ch. Soeger, U. v. d. Ohe
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
@@ -192,7 +192,7 @@ ConeProperties treated_as_hom_props(){
     ret.set(ConeProperty::WeightedEhrhartQuasiPolynomial);
     ret.set(ConeProperty::VirtualMultiplicity);
     ret.set(ConeProperty::EhrhartSeries);
-    ret.set(ConeProperty::Triangulation);
+    ret.set(ConeProperty::LatticePointTriangulation);
     ret.set(ConeProperty::ConeDecomposition);
     ret.set(ConeProperty::StanleyDec);
     ret.set(ConeProperty::Volume);
@@ -206,7 +206,6 @@ ConeProperties treated_as_hom_props(){
 ConeProperties only_homogeneous_props(){
     static ConeProperties ret;
     ret.set(ConeProperty::Deg1Elements);
-    ret.set(ConeProperty::ExcludedFaces);
     ret.set(ConeProperty::Dehomogenization);
     ret.set(ConeProperty::WitnessNotIntegrallyClosed);
     ret.set(ConeProperty::GeneratorOfInterior);
@@ -216,12 +215,8 @@ ConeProperties only_homogeneous_props(){
     ret.set(ConeProperty::IsReesPrimary);
     ret.set(ConeProperty::ReesPrimaryMultiplicity);
     ret.set(ConeProperty::IsGorenstein);
-    ret.set(ConeProperty::InclusionExclusionData);
-    ret.set(ConeProperty::Symmetrize);
-    ret.set(ConeProperty::NoSymmetrization);
     ret.set(ConeProperty::ClassGroup);
     ret.set(ConeProperty::UnitGroupIndex);
-    ret.set(ConeProperty::UnimodularTriangulation);
     return ret;
 }
 
@@ -240,8 +235,8 @@ ConeProperties all_full_cone_goals(bool renf) {
     ret.set(ConeProperty::IsPointed);
     ret.set(ConeProperty::IsIntegrallyClosed);
     ret.set(ConeProperty::IsEmptySemiOpen); 
-    ret.set(ConeProperty::Triangulation);
-    ret.set(ConeProperty::StanleyDec);
+    ret.set(ConeProperty::BasicTriangulation);
+    ret.set(ConeProperty::BasicStanleyDec);
     ret.set(ConeProperty::ConeDecomposition);    
     ret.set(ConeProperty::Automorphisms);
     ret.set(ConeProperty::RationalAutomorphisms);
@@ -408,6 +403,11 @@ void ConeProperties::set_preconditions(bool inhomogeneous, bool numberfield) {
         if (!inhomogeneous)
             CPs.set(ConeProperty::Grading);
     }
+    
+    if (CPs.test(ConeProperty::ExtremeRaysFloat)) {
+        CPs.set(ConeProperty::SupportHyperplanes);
+        CPs.set(ConeProperty::ExtremeRays);
+    }
 
     // SuppHypsFloat ==> SupportHyperplanes 
     if (CPs.test(ConeProperty::SuppHypsFloat)) {
@@ -478,10 +478,17 @@ void ConeProperties::set_preconditions(bool inhomogeneous, bool numberfield) {
     if (CPs.test(ConeProperty::ConeDecomposition))
         CPs.set(ConeProperty::Triangulation);
     
+    // Stanley decompition  ==> Triangulation
+    if (CPs.test(ConeProperty::StanleyDec)){
+        CPs.set(ConeProperty::Triangulation);
+        CPs.set(ConeProperty::BasicStanleyDec);
+    }    
+    
     // refined triangulation ==> Triangulation
     if (CPs.test(ConeProperty::UnimodularTriangulation) || CPs.test(ConeProperty::LatticePointTriangulation)
-                        || CPs.test(ConeProperty::AllGeneratorsTriangulation))
-        CPs.set(ConeProperty::Triangulation);
+                        || CPs.test(ConeProperty::AllGeneratorsTriangulation) 
+                        || CPs.test(ConeProperty::Triangulation) )
+        CPs.set(ConeProperty::BasicTriangulation);
 
     // NoGradingDenom ==> Grading
     if (CPs.test(ConeProperty::GradingDenom))
@@ -506,15 +513,19 @@ void ConeProperties::set_preconditions(bool inhomogeneous, bool numberfield) {
     // Integral ==> Triangulation
     if (CPs.test(ConeProperty::Integral)) {
         // CPs.set(ConeProperty::Multiplicity);
-        CPs.set(ConeProperty::Triangulation);
+        CPs.set(ConeProperty::BasicTriangulation);
     }
 
     // VirtualMultiplicity ==> Triangulation
     if (CPs.test(ConeProperty::VirtualMultiplicity)) {
-        // CPs.set(ConeProperty::Multiplicity);
-        CPs.set(ConeProperty::Triangulation);
+//         // CPs.set(ConeProperty::Multiplicity);
+        CPs.set(ConeProperty::BasicTriangulation);
     }
 
+    // we want an ordinary triangulation if one is asked for
+    if(CPs.test(ConeProperty::BasicTriangulation) && !numberfield)
+        CPs.set(ConeProperty::NoSubdivision);
+
     // WeightedEhrhartQuasiPolynomial ==> WeightedEhrhartSeries
     if (CPs.test(ConeProperty::WeightedEhrhartQuasiPolynomial))
         CPs.set(ConeProperty::WeightedEhrhartSeries);
@@ -522,7 +533,7 @@ void ConeProperties::set_preconditions(bool inhomogeneous, bool numberfield) {
     // WeightedEhrhart ==> StanleyDec
     if (CPs.test(ConeProperty::WeightedEhrhartSeries)) {
         // CPs.set(ConeProperty::Multiplicity);
-        CPs.set(ConeProperty::StanleyDec);
+        CPs.set(ConeProperty::BasicStanleyDec);
     }
 
     // Volume + Integral ==> NoGradingDenom
@@ -609,6 +620,7 @@ void ConeProperties::check_Q_permissible(bool after_implications) {
     copy.reset(ConeProperty::VerticesOfPolyhedron);
     copy.reset(ConeProperty::KeepOrder);
     copy.reset(ConeProperty::Triangulation);
+    copy.reset(ConeProperty::BasicTriangulation);
     copy.reset(ConeProperty::LatticePointTriangulation);
     copy.reset(ConeProperty::AllGeneratorsTriangulation);
     copy.reset(ConeProperty::ConeDecomposition);
@@ -642,6 +654,7 @@ void ConeProperties::check_Q_permissible(bool after_implications) {
     copy.reset(ConeProperty::GradingIsPositive);
     copy.reset(ConeProperty::VerticesFloat);
     copy.reset(ConeProperty::SuppHypsFloat);
+    copy.reset(ConeProperty::ExtremeRaysFloat);
     copy.reset(ConeProperty::FaceLattice);
     copy.reset(ConeProperty::FVector);
     copy.reset(ConeProperty::Incidence);
@@ -657,6 +670,7 @@ void ConeProperties::check_Q_permissible(bool after_implications) {
     copy.reset(ConeProperty::TestLargePyramids);
     copy.reset(ConeProperty::TestSmallPyramids);
     copy.reset(ConeProperty::FullConeDynamic);
+    copy.reset(ConeProperty::ExcludedFaces);
 
     if (after_implications) {
         copy.reset(ConeProperty::Multiplicity);
@@ -698,7 +712,7 @@ void ConeProperties::check_conflicting_variants() {
 
 void ConeProperties::check_sanity(bool inhomogeneous) {  //, bool input_automorphisms) {
 
-    if (CPs.test(ConeProperty::IsTriangulationNested) || CPs.test(ConeProperty::IsTriangulationPartial))
+    if (CPs.test(ConeProperty::IsTriangulationNested) || CPs.test(ConeProperty::IsTriangulationPartial) )
         throw BadInputException("ConeProperty not allowed in compute().");
 
     if ((CPs.test(ConeProperty::Approximate) || CPs.test(ConeProperty::DualMode)) && CPs.test(ConeProperty::NumberLatticePoints))
@@ -712,11 +726,24 @@ void ConeProperties::check_sanity(bool inhomogeneous) {  //, bool input_automorp
     if(CPs.test(ConeProperty::AllGeneratorsTriangulation))
         nr_triangs++;
     
-    if(nr_triangs >0 && CPs.test(ConeProperty::ConeDecomposition))
-        throw BadInputException("ConeDecomposition cannot be combined with refined triangulation");
+    if(nr_triangs >0 && (CPs.test(ConeProperty::ConeDecomposition) || CPs.test(ConeProperty::StanleyDec) ) )
+        throw BadInputException("ConeDecomposition or StanleyDec cannot be combined with refined triangulation");
+    
+    if(CPs.test(ConeProperty::Triangulation))
+        nr_triangs++;
 
     if(nr_triangs > 1)
-        throw BadInputException("Only one type of triangulation allowed.");     
+        throw BadInputException("Only one type of triangulation allowed.");
+    
+    
+    bool something_to_do_primal = CPs.test(ConeProperty::FaceLattice)|| CPs.test(ConeProperty::FVector)
+                                            || CPs.test(ConeProperty::Incidence);
+                                            
+    bool something_to_do_dual = CPs.test(ConeProperty::DualFaceLattice)|| CPs.test(ConeProperty::DualFVector)
+                                            || CPs.test(ConeProperty::DualIncidence);
+                                            
+    if(something_to_do_dual && something_to_do_primal)
+        throw BadInputException("Only one of primal or dual face lattice/f-vector/incidence allowed");
 
     size_t automs = 0;
     if (CPs.test(ConeProperty::Automorphisms))
@@ -754,9 +781,11 @@ vector<string> initializeCPN() {
     CPN.at(ConeProperty::VerticesOfPolyhedron) = "VerticesOfPolyhedron";
     CPN.at(ConeProperty::SupportHyperplanes) = "SupportHyperplanes";
     CPN.at(ConeProperty::SuppHypsFloat) = "SuppHypsFloat";
+    CPN.at(ConeProperty::ExtremeRaysFloat) = "ExtremeRaysFloat";
     CPN.at(ConeProperty::TriangulationSize) = "TriangulationSize";
     CPN.at(ConeProperty::TriangulationDetSum) = "TriangulationDetSum";
     CPN.at(ConeProperty::Triangulation) = "Triangulation";
+    CPN.at(ConeProperty::BasicTriangulation) = "BasicTriangulation";
     CPN.at(ConeProperty::UnimodularTriangulation) = "UnimodularTriangulation";
     CPN.at(ConeProperty::LatticePointTriangulation) = "LatticePointTriangulation";
     CPN.at(ConeProperty::AllGeneratorsTriangulation) = "AllGeneratorsTriangulation";
@@ -783,6 +812,7 @@ vector<string> initializeCPN() {
     CPN.at(ConeProperty::IsReesPrimary) = "IsReesPrimary";
     CPN.at(ConeProperty::ReesPrimaryMultiplicity) = "ReesPrimaryMultiplicity";
     CPN.at(ConeProperty::StanleyDec) = "StanleyDec";
+    CPN.at(ConeProperty::BasicStanleyDec) = "BasicStanleyDec";
     CPN.at(ConeProperty::ExcludedFaces) = "ExcludedFaces";
     CPN.at(ConeProperty::Dehomogenization) = "Dehomogenization";
     CPN.at(ConeProperty::InclusionExclusionData) = "InclusionExclusionData";
@@ -870,7 +900,7 @@ vector<string> initializeCPN() {
     CPN.at(ConeProperty::Static) = "Static";
 
     // detect changes in size of Enum, to remember to update CPN!
-    static_assert(ConeProperty::EnumSize == 118, "ConeProperties Enum size does not fit! Update cone_property.cpp!");
+    static_assert(ConeProperty::EnumSize == 121, "ConeProperties Enum size does not fit! Update cone_property.cpp!");
     // assert all fields contain an non-empty string
     for (size_t i = 0; i < ConeProperty::EnumSize; i++) {
         assert(CPN.at(i).size() > 0);
