@@ -1,6 +1,6 @@
 /*
  * Normaliz
- * Copyright (C) 2007-2019  Winfried Bruns, Bogdan Ichim, Christof Soeger
+ * Copyright (C) 2007-2021  W. Bruns, B. Ichim, Ch. Soeger, U. v. d. Ohe
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
@@ -181,6 +181,7 @@ class Full_Cone {
     renf_elem_class renf_multiplicity;
 #endif
     Matrix<Integer> Generators;
+    Matrix<Integer> InputGenerators; // stores purified input -- Generators can be extended
     set<vector<Integer>> Generator_Set;  // the generators as a set (if needed)
     Matrix<nmz_float> Generators_float;  // floatung point approximations to the generators
     vector<key_t> PermGens;              // stores the permutation of the generators created by sorting
@@ -464,7 +465,7 @@ class Full_Cone {
     void minimize_excluded_faces();
     void prepare_inclusion_exclusion();
 
-    void set_implications();
+    void set_preconditions();
     void set_primal_algorithm_control_variables();
     void reset_tasks();
     void deactivate_completed_tasks();
