@@ -1,6 +1,6 @@
 /*
  * Normaliz
- * Copyright (C) 2007-2019  Winfried Bruns, Bogdan Ichim, Christof Soeger
+ * Copyright (C) 2007-2021  W. Bruns, B. Ichim, Ch. Soeger, U. v. d. Ohe
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
@@ -135,13 +135,7 @@ void makeMM_euclidean(BinaryMatrix<Integer>& MM, const Matrix<Integer>& Generato
     for(size_t j=0; j< VV.size(); ++j){
         long old_index=Values[VV[j]];
         new_index[old_index]=j;
-    }    
-
-
-    for (i = 0; i < mm; ++i) {
-        for (j = 0; j < nn; ++j)
-            MM.insert(MVal[i][j], i, j);
-    }
+    } 
     
     for (i = 0; i < mm; ++i) {
         for (j = 0; j < nn; ++j){
@@ -220,6 +214,7 @@ void makeMM(BinaryMatrix<Integer>& MM, const Matrix<Integer>& Generators, const
     }
     
      MM.set_values(VV);
+
 }
 
 template <typename Integer>
