@@ -1,6 +1,6 @@
 /*
  * Normaliz
- * Copyright (C) 2007-2019  Winfried Bruns, Bogdan Ichim, Christof Soeger
+ * Copyright (C) 2007-2021  W. Bruns, B. Ichim, Ch. Soeger, U. v. d. Ohe
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
@@ -168,7 +168,7 @@ void Output<renf_elem_class>::write_renf(ostream& os) const {
         os << "Real embedded number field:" << endl;
         // os << *Renf << endl;
         char *res, *res1;
-        res = fmpq_poly_get_str_pretty(Renf->get_renf()->nf->pol, "a");
+        res = fmpq_poly_get_str_pretty(Renf->get_renf()->nf->pol, Renf->gen_name.c_str());
         res1 = arb_get_str(Renf->get_renf()->emb, 64, 0);
         os << "min_poly "
            << "(" << res << ")"
@@ -431,7 +431,7 @@ void Output<Integer>::write_perms_and_orbits(ofstream& out,
     out << endl;
 
     out << "Cycle decompositions " << endl << endl;
-    ;
+
     for (size_t i = 0; i < nr_items; ++i) {
         vector<vector<libnormaliz::key_t> > dec = cycle_decomposition(Perms[i]);
         out << "Perm " << i + 1 << ": ";
@@ -499,38 +499,38 @@ void Output<Integer>::write_tri() const {
         string file_name = name + ".tri";
         ofstream out(file_name.c_str());
 
-        const vector<pair<vector<libnormaliz::key_t>, Integer> >& Tri = Result->getTriangulation();
-        const vector<vector<bool> >& Dec =
-            Result->isComputed(ConeProperty::ConeDecomposition) ? Result->getOpenFacets() : vector<vector<bool> >();
-        auto idd = Dec.begin();
+        const pair<vector<SHORTSIMPLEX<Integer> >, Matrix<Integer> >& Tri = Result->getTriangulation();
+        //const vector<vector<bool> >& Dec =
+        //    Result->isComputed(ConeProperty::ConeDecomposition) ? Result->getOpenFacets() : vector<vector<bool> >();
+        // auto idd = Dec.begin();
 
-        out << Tri.size() << endl;
+        out << Tri.first.size() << endl;
         size_t nr_extra_entries = 1;
         if (Result->isComputed(ConeProperty::ConeDecomposition))
             nr_extra_entries += Result->getSublattice().getRank() - Result->getDimMaximalSubspace();
         out << Result->getSublattice().getRank() - Result->getDimMaximalSubspace() + nr_extra_entries
             << endl;  // works also for empty list
 
-        for (const auto& tit : Tri) {
-            for (size_t i = 0; i < tit.first.size(); i++) {
-                out << tit.first[i] + 1 << " ";
+        for (const auto& tit : Tri.first) {
+            for (size_t i = 0; i < tit.key.size(); i++) {
+                out << tit.key[i] + 1 << " ";
             }
-            out << "   " << tit.second;
+            out << "   " << tit.vol;
             if (Result->isComputed(ConeProperty::ConeDecomposition)) {
                 out << "   ";
-                for (size_t i = 0; i < tit.first.size(); i++) {
-                    out << " " << (*idd)[i];
+                for (size_t i = 0; i < tit.key.size(); i++) {
+                    out << " " << tit.Excluded[i];
                 }
-                idd++;
+                // idd++;
             }
             out << endl;
         }
-        if (Result->isTriangulationNested())
+        /* if (Result->isTriangulationNested())
             out << "nested" << endl;
         else
             out << "plain" << endl;
         if (Result->isTriangulationPartial())
-            out << "partial" << endl;
+            out << "partial" << endl;*/
         out.close();
     }
 }
@@ -672,7 +672,7 @@ void Output<Integer>::write_Stanley_dec() const {
         }
 
         out << "Stanley_dec" << endl;
-        const list<STANLEYDATA<Integer> >& StanleyDec = Result->getStanleyDec();
+        const list<STANLEYDATA<Integer> >& StanleyDec = Result->getStanleyDec().first; // generators not needed here
         auto S = StanleyDec.begin();
         size_t i;
 
@@ -940,7 +940,7 @@ void Output<Integer>::writeWeightedEhrhartSeries(ofstream& out) const {
     if (HS.get_expansion_degree() > -1) {
         vector<mpz_class> expansion = HS.getExpansion();
         out << "Expansion of weighted Ehrhart series" << endl;
-        for (size_t i = 0; i < expansion.size(); ++i)
+        for (long i = 0; i < (long) expansion.size(); ++i)
             out << i + HS.getShift() << ": " << expansion[i] << endl;
         out << "Common denominator of coefficients: ";
         out << Result->getIntData().getWeightedEhrhartSeries().second << endl;
@@ -1109,9 +1109,9 @@ void Output<Integer>::write_files() const {
         }
         esp_out.close();
     }
-    if (tgn && Result->isComputed(ConeProperty::Generators))
-        Result->getGeneratorsMatrix().print(name, "tgn");
-    if (tri && Result->isComputed(ConeProperty::Triangulation)) {  // write triangulation
+    if (tgn && (Result->getTriangulation().first.size() > 0 || Result->isComputed(ConeProperty::StanleyDec)) )
+        Result->getTriangulation().second.print(name, "tgn");
+    if (tri &&  Result->getTriangulation().first.size() > 0) {  // write triangulation
         write_tri();
     }
 
@@ -1497,16 +1497,19 @@ void Output<Integer>::write_files() const {
             out << Result->getNrVerticesOfPolyhedron() << " vertices of polyhedron:" << endl;
             if (Result->isComputed(ConeProperty::VerticesFloat))
                 Result->getVerticesFloatMatrix().pretty_print(
-                    out);  // write_float(out,Result->getVerticesFloatMatrix(),Result->getNrVerticesFloat(),dim);
+                    out);  
             else
                 Result->getVerticesOfPolyhedronMatrix().pretty_print(out);
             out << endl;
         }
         if (Result->isComputed(ConeProperty::ExtremeRays) && !no_ext_rays_output) {
             out << Result->getNrExtremeRays() << " extreme rays" << of_cone << ":" << endl;
-            if (homogeneous && Result->isComputed(ConeProperty::VerticesFloat))
-                Result->getVerticesFloatMatrix().pretty_print(
-                    out);  // write_float(out,Result->getVerticesFloatMatrix(),Result->getNrVerticesFloat(),dim);
+            if (homogeneous && (Result->isComputed(ConeProperty::VerticesFloat) || Result->isComputed(ConeProperty::VerticesFloat)) ){
+                if(Result->isComputed(ConeProperty::VerticesFloat))
+                    Result->getVerticesFloatMatrix().pretty_print(out);
+                else
+                    Result->getExtremeRaysFloatMatrix().pretty_print(out);
+            }
             else
                 Result->getExtremeRaysMatrix().pretty_print(out);
             out << endl;
